<?php

namespace app\controllers;

use Yii;
use yii\filters\AccessControl;
use yii\web\Controller;
use yii\web\Response;
use yii\filters\VerbFilter;
use app\models\LoginForm;
use app\models\ContactForm;
use app\models\PaiementForm;
use app\models\Paiement;
use yii\helpers\VarDumper;
use yii\helpers\Url;
use app\components\PaiementRetrieverJob;

class SiteController extends Controller
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'only' => ['logout'],
                'rules' => [
                    [
                        'actions' => ['logout'],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'logout' => ['post'],
                ],
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function actions()
    {
        return [
            'error' => [
                'class' => 'yii\web\ErrorAction',
            ],
            'captcha' => [
                'class' => 'yii\captcha\CaptchaAction',
                'fixedVerifyCode' => YII_ENV_TEST ? 'testme' : null,
            ],
        ];
    }

    /**
     * Displays payment page.
     *
     * @return string
     */
    public function actionIndex()
    {
        if (defined('RETURN_URL'))
            $return_url=RETURN_URL;
        if (defined('AMOUNT'))
            $amount=AMOUNT;
        if(isset(Yii::$app->request->queryParams['return_url']))
            $return_url=Yii::$app->request->queryParams['return_url'];
        if(isset(Yii::$app->request->queryParams['amount']))
            $amount=Yii::$app->request->queryParams['amount'];
        $paiementForm=new PaiementForm();
        if ($paiementForm->load(Yii::$app->request->post()) && $paiementForm->validate() && $paiement=$paiementForm->fetch()) {
            $paiement->save();
            $paiement->refresh();
            $return_url=str_replace('%ID%', $paiement->id, $return_url);
            $this->redirect($return_url);
        }
        return $this->render('index', ['paiementForm' => $paiementForm,
                                       'return_url' => $return_url,
                                       'amount' => $amount,
                                     ]);
    }

    /**
     * incoming action: receives paiement id from MPay server and enqueues job to retrieve data
     *
     * @return Response|string
     */
    public function  actionIncoming($recordId)
    {
        $job=new PaiementRetrieverJob(['remoteId' => $recordId]);
        Yii::$app->queue->push($job);
        Yii::$app->response->statusCode = 200;
        return;
    }
    // public function actionLogin()
    // {
    //     if (!Yii::$app->user->isGuest) {
    //         return $this->goHome();
    //     }
    //
    //     $model = new LoginForm();
    //     if ($model->load(Yii::$app->request->post()) && $model->login()) {
    //         return $this->goBack();
    //     }
    //     return $this->render('login', [
    //         'model' => $model,
    //     ]);
    // }

    /**
     * Logout action.
     *
     * @return Response
     */
    // public function actionLogout()
    // {
    //     Yii::$app->user->logout();
    //
    //     return $this->goHome();
    // }

    /**
     * Displays contact page.
     *
     * @return Response|string
     */
    // public function actionContact()
    // {
    //     $model = new ContactForm();
    //     if ($model->load(Yii::$app->request->post()) && $model->contact(Yii::$app->params['adminEmail'])) {
    //         Yii::$app->session->setFlash('contactFormSubmitted');
    //
    //         return $this->refresh();
    //     }
    //     return $this->render('contact', [
    //         'model' => $model,
    //     ]);
    // }

    /**
     * Displays about page.
     *
     * @return string
     */
    // public function actionAbout()
    // {
    //     return $this->render('about');
    // }
}
