<?php

namespace app\models;

use Yii;
use DateTime;
use ZipArchive;
use yii\db\Query;
use yii\db\Expression;
use yii\db\ActiveRecord;
use yii\db\QueryBuilder;
use yii\web\BadRequestHttpException;
use yii\web\ServerErrorHttpException;
use yii\helpers\VarDumper;
use yii\behaviors\BlameableBehavior;
use yii\behaviors\TimestampBehavior;
use app\models\PaiementQuery;

/**
 * This is the model class for table "paiement".
 *
 * @property int $id
 * @property string $type type de transaction (recharge|transfertEnvoi|transfertReception...)
 * @property string $transaction_id ID transaction, attribué par le prestataire (Orange, Telmob)
 * @property int $amount montant du transfert recu (à porter au crédit)
 * @property int $amount_debit montant du transfert envoyé (à porter au débit)
 * @property string $statut statut de l'opération: OK si le paiement a été enregistré
 * @property int $date date transaction tel qu'indiquée dans le SMS
 * @property string $last_modified datetime, équivaut à l'heure de l'enregistrement du paiement par un utilisateur
 * @property string $creation_date date de création de l'enregistrement
 * @property string $reseau Operateur de la transaction (MOBICASH|OrangeMoney)
 * @property string $original_sms SMS tel que reçu de l'operateur
 * @property int $original_timestamp timestamp du SMS d'origine (fourni par le client Android)
 * @property string $original_sender telephone de l'expediteur de l'argent
 * @property string $nom_expediteur nom de celui qui a fait l'envoi tel qu'indique dans le SMS de l'operateur
 * @property string $numero_destinataire numéro destinataire du transfert
 * @property string $nom_destinataire nom du destinataire du transfert
 * @property int $solde Solde du compte après opération
 */
class Paiement extends \yii\db\ActiveRecord
{
  const STATUS_PENDING = "Pending";
  const STATUS_OK = "OK";
  const STATUS_ERROR = "Error";

  const CHAMPS = [
      'id', 'type', 'transaction_id', 'amount', 'amount_debit', 'statut', 'date', 'last_modified',
      'creation_date', 'reseau', 'original_sms', 'original_timestamp', 'original_sender', 'nom_expediteur',
      'numero_destinataire', 'nom_destinataire', 'solde',
    ];

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%paiement}}';
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('app', 'ID'),
            'type' => Yii::t('app', 'Type d\'Opération'),
            'transaction_id' => Yii::t('app', 'Id Transaction'),
            'amount' => Yii::t('app', 'Montant Crédit'),
            'amount_debit' => Yii::t('app', 'Montant Débit'),
            'statut' => Yii::t('app', 'Statut'),
            'date' => Yii::t('app', 'Date'),
            'last_modified' => Yii::t('app', 'Dern. MAJ'),
            'creation_date' => Yii::t('app', 'Date Création'),
            'reseau' => Yii::t('app', 'Réseau'),
            'original_sms' => Yii::t('app', 'SMS d\'origine'),
            'original_timestamp' => Yii::t('app', 'Date du SMS d\'origine'),
            'original_sender' => Yii::t('app', 'Numéro Expéditeur'),
            'nom_expediteur' => Yii::t('app', 'Nom Expéditeur'),
            'numero_destinataire' => Yii::t('app', 'Numero Destinataire'),
            'nom_destinataire' => Yii::t('app', 'Nom Destinataire'),
            'solde' => Yii::t('app', 'Solde après opération'),
 		        ];
    }

    public function behaviors()
    {
        return [
            [
                'class' => TimestampBehavior::class,
                'value' => function ($event) { return date(DATETIME_FORMAT); },
                'attributes' => [
                          ActiveRecord::EVENT_BEFORE_INSERT => ['creation_date', 'last_modified'],
                          ActiveRecord::EVENT_BEFORE_UPDATE => ['last_modified'],
                ],

            ],
        ];
    }

    public function fields()
    {
        $fields=parent::fields();
        return $fields;
    }


    /**
     * @inheritdoc
     * @return PaiementQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new PaiementQuery(get_called_class());
    }

}
